@@ -312,7 +312,7 @@ def drive_download(link: str, file_path: str = "", filename: str = ""):
     os.makedirs(file_path, exist_ok=True)
     output = f"{file_path}/{filename}" if filename else f"{file_path}/"
     file = gdown.download(link, output, fuzzy=True)
-    if ".pdf" not in file:
+    if not file or ".pdf" not in file:
         print_message(3, [filename, link])
         logerror(3, [f"{file_path}/{filename}", link])
 
